
From: Andi Kleen <ak@suse.de>

Add links for p4-clockmod driver in x86-64 cpufreq. 

AK: Made it dependent on EMBEDDED because the driver is only
useful in some special situations and should be normally not used.

Signed-off-by: "Venkatesh Pallipadi" <venkatesh.pallipadi@intel.com>
Signed-off-by: Andi Kleen <ak@suse.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/x86_64/kernel/cpufreq/Kconfig  |   24 ++++++++++++++++++++++++
 25-akpm/arch/x86_64/kernel/cpufreq/Makefile |    4 ++++
 2 files changed, 28 insertions(+)

diff -puN arch/x86_64/kernel/cpufreq/Kconfig~x86_64-add-p4-clockmod arch/x86_64/kernel/cpufreq/Kconfig
--- 25/arch/x86_64/kernel/cpufreq/Kconfig~x86_64-add-p4-clockmod	Mon Nov  1 14:52:49 2004
+++ 25-akpm/arch/x86_64/kernel/cpufreq/Kconfig	Mon Nov  1 14:52:49 2004
@@ -76,5 +76,29 @@ config X86_ACPI_CPUFREQ_PROC_INTF
 
 	  If in doubt, say N.
 
+config X86_P4_CLOCKMOD
+	tristate "Intel Pentium 4 clock modulation"
+	depends on CPU_FREQ_TABLE && EMBEDDED
+	help
+	  This adds the clock modulation driver for Intel Pentium 4 / XEON
+	  processors.  When enabled it will lower CPU temperature by skipping
+	  clocks.
+
+	  This driver should be only used in exceptional
+	  circumstances when very low power is needed because it causes severe
+	  slowdowns and noticeable latencies.  Normally Speedstep should be used
+	  instead.
+
+	  For details, take a look at <file:Documentation/cpu-freq/>.
+
+	  Unless you are absolutely sure say N.
+
+
+config X86_SPEEDSTEP_LIB
+        tristate
+        depends on (X86_P4_CLOCKMOD)
+        default (X86_P4_CLOCKMOD)
+
+
 endmenu
 
diff -puN arch/x86_64/kernel/cpufreq/Makefile~x86_64-add-p4-clockmod arch/x86_64/kernel/cpufreq/Makefile
--- 25/arch/x86_64/kernel/cpufreq/Makefile~x86_64-add-p4-clockmod	Mon Nov  1 14:52:49 2004
+++ 25-akpm/arch/x86_64/kernel/cpufreq/Makefile	Mon Nov  1 14:52:49 2004
@@ -7,7 +7,11 @@ SRCDIR := ../../../i386/kernel/cpu/cpufr
 obj-$(CONFIG_X86_POWERNOW_K8) += powernow-k8.o
 obj-$(CONFIG_X86_SPEEDSTEP_CENTRINO) += speedstep-centrino.o
 obj-$(CONFIG_X86_ACPI_CPUFREQ) += acpi-cpufreq.o
+obj-$(CONFIG_X86_P4_CLOCKMOD) += p4-clockmod.o
+obj-$(CONFIG_X86_SPEEDSTEP_LIB) += speedstep-lib.o
 
 powernow-k8-objs := ${SRCDIR}/powernow-k8.o
 speedstep-centrino-objs := ${SRCDIR}/speedstep-centrino.o
 acpi-cpufreq-objs := ${SRCDIR}/acpi-cpufreq.o
+p4-clockmod-objs := ${SRCDIR}/p4-clockmod.o
+speedstep-lib-objs := ${SRCDIR}/speedstep-lib.o
_
